@@ -73,29 +73,29 @@ FtpSession::FtpSession(TQObject *parent, const char *name)
 	m_iconencrypted = TDEGlobal::iconLoader()->loadIconSet("encrypted",TDEIcon::Small).pixmap(TQIconSet::Small,TQIconSet::Normal);
    m_iconunencrypted = TDEGlobal::iconLoader()->loadIconSet("encrypted",TDEIcon::Small).pixmap(TQIconSet::Small,TQIconSet::Disabled);
 	
-	connect(mp_eventhandler, SIGNAL(ftp_log(TQString, bool)), SLOT(SLOT_Log(TQString, bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_connect(bool)), SLOT(SLOT_Connect(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_login(bool)), SLOT(SLOT_Login(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_xfered(off64_t, bool)), SLOT(SLOT_Xfered(off64_t, bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_quit(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_chdir(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_raw(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_get(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_put(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_fxp(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_rm(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_authtls(bool)), SLOT(SLOT_AuthTls(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_misc(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_mkdir(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_rename(bool)), SLOT(SLOT_Misc(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_pwd(bool, TQString)), SLOT(SLOT_Pwd(bool, TQString)));
-	connect(mp_eventhandler, SIGNAL(ftp_dir(bool, list<KbFileInfo*>, list<KbFileInfo*>)), 
-		SLOT(SLOT_Dir(bool, list<KbFileInfo*>, list<KbFileInfo*>)));
-	connect(mp_eventhandler, SIGNAL(ftp_encryptdata(bool)), SLOT(SLOT_EncryptData(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_finished()), SLOT(SLOT_Finish()));
-	connect(mp_eventhandler, SIGNAL(ftp_connectionlost()), SLOT(SLOT_ConnectionLost()));
-	connect(mp_eventhandler, SIGNAL(ftp_transfer(bool)), SLOT(SLOT_Transfer(bool)));
-	connect(mp_eventhandler, SIGNAL(ftp_scandir(bool, KbDirInfo*)), SLOT(SLOT_Scandir(bool, KbDirInfo*)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_log(TQString, bool)), TQ_SLOT(SLOT_Log(TQString, bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_connect(bool)), TQ_SLOT(SLOT_Connect(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_login(bool)), TQ_SLOT(SLOT_Login(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_xfered(off64_t, bool)), TQ_SLOT(SLOT_Xfered(off64_t, bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_quit(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_chdir(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_raw(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_get(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_put(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_fxp(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_rm(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_authtls(bool)), TQ_SLOT(SLOT_AuthTls(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_misc(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_mkdir(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_rename(bool)), TQ_SLOT(SLOT_Misc(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_pwd(bool, TQString)), TQ_SLOT(SLOT_Pwd(bool, TQString)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_dir(bool, list<KbFileInfo*>, list<KbFileInfo*>)), 
+		TQ_SLOT(SLOT_Dir(bool, list<KbFileInfo*>, list<KbFileInfo*>)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_encryptdata(bool)), TQ_SLOT(SLOT_EncryptData(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_finished()), TQ_SLOT(SLOT_Finish()));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_connectionlost()), TQ_SLOT(SLOT_ConnectionLost()));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_transfer(bool)), TQ_SLOT(SLOT_Transfer(bool)));
+	connect(mp_eventhandler, TQ_SIGNAL(ftp_scandir(bool, KbDirInfo*)), TQ_SLOT(SLOT_Scandir(bool, KbDirInfo*)));
 }
 
 FtpSession::~FtpSession()
@@ -105,7 +105,7 @@ FtpSession::~FtpSession()
 void FtpSession::SetCmdLine(KLineEdit* cmdline)
 { 
 	TDECompletion *comp = cmdline->completionObject();
- 	connect(cmdline, SIGNAL(returnPressed(const TQString&)), comp, SLOT(addItem(const TQString&)));
+ 	connect(cmdline, TQ_SIGNAL(returnPressed(const TQString&)), comp, TQ_SLOT(addItem(const TQString&)));
 	cmdline->setCompletionMode(TDEGlobalSettings::CompletionAuto);
 	mp_cmdline = cmdline;
 }
@@ -113,7 +113,7 @@ void FtpSession::SetCmdLine(KLineEdit* cmdline)
 void FtpSession::SetCwdLine(KLineEdit* cwdline)
 { 
 	TDECompletion *comp = cwdline->completionObject();
- 	connect(cwdline, SIGNAL(returnPressed(const TQString&)), comp, SLOT(addItem(const TQString&)));
+ 	connect(cwdline, TQ_SIGNAL(returnPressed(const TQString&)), comp, TQ_SLOT(addItem(const TQString&)));
 	cwdline->setCompletionMode(TDEGlobalSettings::CompletionAuto);
 	mp_cwdline = cwdline;
 }
@@ -380,7 +380,7 @@ void FtpSession::SLOT_CmdLine()
 		TDEProcess* p = new TDEProcess();
  		p->setWorkingDirectory(m_localworkingdir.absPath());
 		*p << TQStringList::split(" ", mp_cmdline->text());
-		connect(p, SIGNAL(processExited(TDEProcess*)), SLOT(SLOT_LocalProcessExited(TDEProcess*)));
+		connect(p, TQ_SIGNAL(processExited(TDEProcess*)), TQ_SLOT(SLOT_LocalProcessExited(TDEProcess*)));
 		if (p->start() == TRUE) mp_cmdline->setText("");
 	}
 }
